pytilities.geometry.test.testall

Package pytilities :: Package geometry :: Package test :: Module testall |
[hide private]
[frames] | no frames]

# Module testall

source code

Functions | [hide private]
run() | source code

Variables | [hide private]
| test_suite = `<unittest.TestSuite tests=[<unittest.TestSuite te`...``
| __package__ = ``'``pytilities.geometry.test``'``

Variables Details | [hide private]

  ### test_suite Value:
      <unittest.TestSuite tests=[<unittest.TestSuite tests=[<unittest.TestSu
      ite tests=[<unittest.TestSuite tests=[<pytilities.geometry.test.vector
      .BoundVectorTestCase testMethod=test_assign>, <pytilities.geometry.tes
      t.vector.BoundVectorTestCase testMethod=test_boundness>, <pytilities.g
      eometry.test.vector.BoundVectorTestCase testMethod=test_copy>, <pytili
      ties.geometry.test.vector.BoundVectorTestCase testMethod=test_get_xy>,
       <pytilities.geometry.test.vector.BoundVectorTestCase testMethod=test_
      iadd>, <pytilities.geometry.test.vector.BoundVectorTestCase testMethod
      ...